@@ -339,13 +339,9 @@ func TestPushImage(t *testing.T) {
 		t.Errorf("PushImage: Wrong query string. Want no parameters, got %q.", query)
 	}
 
-	auth, err := base64.URLEncoding.DecodeString(req.Header.Get("X-Registry-Auth"))
-	if err != nil {
-		t.Errorf("PushImage: caught error decoding auth. %#v", err.Error())
-	}
-	if strings.TrimSpace(string(auth)) != "{}" {
-		t.Errorf("PushImage: wrong body. Want %q. Got %q.",
-			base64.URLEncoding.EncodeToString([]byte("{}")), req.Header.Get("X-Registry-Auth"))
+	authHeader, ok := req.Header["X-Registry-Auth"]
+	if ok {
+		t.Errorf("PushImage: unexpected non-empty X-Registry-Auth header: %v", authHeader)
 	}
 }
 
@@ -744,6 +740,9 @@ func TestImportImageShouldPassTarContentToBodyWhenSourceIsFilePath(t *testing.T)
 	}
 	req := fakeRT.requests[0]
 	tarContent, err := ioutil.ReadAll(tar)
+	if err != nil {
+		t.Fatal(err)
+	}
 	body, err := ioutil.ReadAll(req.Body)
 	if err != nil {
 		t.Fatal(err)
@@ -1037,6 +1036,7 @@ func TestExportImages(t *testing.T) {
 	var buf bytes.Buffer
 	fakeRT := &FakeRoundTripper{message: "", status: http.StatusOK}
 	client := newTestClient(fakeRT)
+	client.requestedAPIVersion = apiVersion125
 	opts := ExportImagesOptions{Names: []string{"testimage1", "testimage2:latest"}, OutputStream: &buf}
 	err := client.ExportImages(opts)
 	if nil != err {
@@ -1044,12 +1044,24 @@ func TestExportImages(t *testing.T) {
 	}
 	req := fakeRT.requests[0]
 	if req.Method != "GET" {
-		t.Errorf("ExportImage: wrong method. Expected %q. Got %q.", "GET", req.Method)
+		t.Errorf("ExportImages: wrong method. Expected %q. Got %q.", "GET", req.Method)
 	}
-	expected := "http://localhost:4243/images/get?names=testimage1&names=testimage2%3Alatest"
+	expected := "http://localhost:4243/v1.25/images/get?names=testimage1%2Ctestimage2%3Alatest"
 	got := req.URL.String()
 	if !reflect.DeepEqual(got, expected) {
-		t.Errorf("ExportIMage: wrong path. Expected %q. Got %q.", expected, got)
+		t.Errorf("ExportImages: wrong path. Expected %q. Got %q.", expected, got)
+	}
+
+	client.requestedAPIVersion = apiVersion124
+	err = client.ExportImages(opts)
+	if nil != err {
+		t.Error(err)
+	}
+	req = fakeRT.requests[1]
+	expected = "http://localhost:4243/v1.24/images/get?names=testimage1&names=testimage2%3Alatest"
+	got = req.URL.String()
+	if !reflect.DeepEqual(got, expected) {
+		t.Errorf("ExportImages: wrong path. Expected %q. Got %q.", expected, got)
 	}
 }
 
