@@ -6,6 +6,7 @@ package docker
 
 import (
 	"bytes"
+	"encoding/base64"
 	"encoding/json"
 	"net/http"
 	"net/http/httptest"
@@ -13,9 +14,6 @@ import (
 	"reflect"
 	"testing"
 
-	"encoding/base64"
-	"strings"
-
 	"github.com/docker/docker/api/types/swarm"
 )
 
@@ -54,13 +52,9 @@ func TestCreateService(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	auth, err := base64.URLEncoding.DecodeString(req.Header.Get("X-Registry-Auth"))
-	if err != nil {
-		t.Errorf("CreateService: caught error decoding auth. %#v", err.Error())
-	}
-	if strings.TrimSpace(string(auth)) != "{}" {
-		t.Errorf("CreateService: wrong body. Want %q. Got %q.",
-			base64.URLEncoding.EncodeToString([]byte("{}")), req.Header.Get("X-Registry-Auth"))
+	authHeader, ok := req.Header["X-Registry-Auth"]
+	if ok {
+		t.Errorf("CreateService: unexpected non-empty X-Registry-Auth header: %v", authHeader)
 	}
 }
 
@@ -489,7 +483,7 @@ func TestGetServiceLogs(t *testing.T) {
 	}
 }
 
-func TesGetServicetLogsNilStdoutDoesntFail(t *testing.T) {
+func TestGetServicetLogsNilStdoutDoesntFail(t *testing.T) {
 	server := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		prefix := []byte{1, 0, 0, 0, 0, 0, 0, 19}
 		w.Write(prefix)
