@@ -28,7 +28,7 @@ import (
 
 	"github.com/docker/docker/api/types/swarm"
 	"github.com/docker/docker/pkg/stdcopy"
-	"github.com/fsouza/go-dockerclient"
+	docker "github.com/fsouza/go-dockerclient"
 	"github.com/gorilla/mux"
 )
 
@@ -468,7 +468,7 @@ func (s *DockerServer) findImage(id string) (string, error) {
 	if _, ok := s.images[id]; ok {
 		return id, nil
 	}
-	return "", errors.New("No such image")
+	return "", errors.New("no such image")
 }
 
 func (s *DockerServer) createContainer(w http.ResponseWriter, r *http.Request) {
@@ -500,7 +500,7 @@ func (s *DockerServer) createContainer(w http.ResponseWriter, r *http.Request) {
 		}}
 	}
 
-	//the container may not have cmd when using a Dockerfile
+	// the container may not have cmd when using a Dockerfile
 	var path string
 	var args []string
 	if len(config.Cmd) == 1 {
@@ -941,7 +941,7 @@ func (s *DockerServer) findContainerWithLock(idOrName string, shouldLock bool) (
 	if cont, ok := s.containers[idOrName]; ok {
 		return cont, nil
 	}
-	return nil, errors.New("No such container")
+	return nil, errors.New("no such container")
 }
 
 func (s *DockerServer) logContainer(w http.ResponseWriter, r *http.Request) {
@@ -994,7 +994,7 @@ func (s *DockerServer) buildImage(w http.ResponseWriter, r *http.Request) {
 			return
 		}
 	}
-	//we did not use that Dockerfile to build image cause we are a fake Docker daemon
+	// we did not use that Dockerfile to build image cause we are a fake Docker daemon
 	image := docker.Image{
 		ID:      s.generateID(),
 		Created: time.Now(),
@@ -1288,7 +1288,7 @@ func (s *DockerServer) findNetwork(idOrName string) (*docker.Network, int, error
 			return network, i, nil
 		}
 	}
-	return nil, -1, errors.New("No such network")
+	return nil, -1, errors.New("no such network")
 }
 
 func (s *DockerServer) listNetworks(w http.ResponseWriter, r *http.Request) {
@@ -1351,7 +1351,7 @@ func (s *DockerServer) createNetwork(w http.ResponseWriter, r *http.Request) {
 	s.networks = append(s.networks, &network)
 	s.netMut.Unlock()
 	w.WriteHeader(http.StatusCreated)
-	var c = struct{ ID string }{ID: network.ID}
+	c := struct{ ID string }{ID: network.ID}
 	json.NewEncoder(w).Encode(c)
 }
 
@@ -1386,7 +1386,7 @@ func (s *DockerServer) networksConnect(w http.ResponseWriter, r *http.Request) {
 		return
 	}
 
-	if _, found := network.Containers[container.ID]; found == true {
+	if _, found := network.Containers[container.ID]; found {
 		http.Error(w, "endpoint already exists in network", http.StatusBadRequest)
 		return
 	}
